@@ -6,9 +6,9 @@ package BSON::Bool;
 # ABSTRACT: Legacy BSON type wrapper for Booleans (DEPRECATED)
 
 use version;
-our $VERSION = 'v0.999.4'; # TRIAL
+our $VERSION = 'v0.999.5'; # TRIAL
 
-use boolean ();
+use boolean 0.45 ();
 our @ISA = qw/boolean/;
 
 sub new {
@@ -44,7 +44,7 @@ BSON::Bool - Legacy BSON type wrapper for Booleans (DEPRECATED)
 
 =head1 VERSION
 
-version v0.999.4
+version v0.999.5
 
 =head1 DESCRIPTION
 
